<?php


/**
 * Plugin implementation of EphotoDam Field formatter.
 * FieldFormatter(
 *   id = "ephoto_dam_field_formatter",
 *   label = @Translation("Ephoto Dam Field"),
 *   field_types = {
 *     "ephoto_dam_field"
 *   }
 * )
 * PHP version 8
 * 
 * @category Fiel_Formatter
 * @package  Ephoto-Drupal
 * @author   Einden <contact@einden.fr>
 * @license  https://www.ephoto.fr/ Einden
 * @link     https://www.ephoto.fr/
 */

namespace Drupal\ephoto_dam_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

 /**
  * Validates the EphotoDam Field
  * 
  * @category Fiel_Formatter
  * @package  Ephoto-Drupal
  * @author   Einden <contact@einden.fr>
  * @license  https://www.ephoto.fr/ Einden
  * @link     https://www.ephoto.fr/
  */
class EphotoDamFieldFormatter
extends FormatterBase
implements ContainerFactoryPluginInterface
{
    /**
     * Constructs a new instance of the plugin.
     *
     * @param string                                      $plugin_id            
     *                                                                          The plugin_id for the formatter.
     * @param mixed                                       $plugin_definition    
     *                                                                          The plugin implementation definition.
     * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition     
     *                                                                          The definition of the field to which the formatter is associated.
     * @param array                                       $settings             
     *                                                                          The formatter settings.
     * @param string                                      $label                
     *                                                                          The formatter label display setting.
     * @param string                                      $view_mode            
     *                                                                          The
     *                                                                          view
     *                                                                          mode.
     * @param array                                       $third_party_settings 
     *                                                                          Third party settings.
     */
    public function __construct(
        $plugin_id,
        $plugin_definition, 
        FieldDefinitionInterface $field_definition, 
        $settings,
        $label, 
        $view_mode, 
        $third_party_settings
    ) {
        parent::__construct(
            $plugin_id,
            $plugin_definition, 
            $field_definition, 
            $settings, $label, 
            $view_mode, 
            $third_party_settings
        );
    }

    /**
     * Create the Field Formatter
     * 
     * @param ContainerInterface $container         
     *                                              the container
     * @param array              $configuration     
     *                                              the configuration
     *                                              of the field formatter
     * @param string             $plugin_id         
     *                                              the id of the 
     *                                              formatter
     * @param mixed              $plugin_definition 
     *                                              the plugin 
     *                                              implementation definition
     * 
     *                                              {@inheritdoc}
     * 
     * @return EphotoDamFieldFormatter
     */
    public static function create(
        ContainerInterface $container, 
        array $configuration, 
        $plugin_id, 
        $plugin_definition
    ) {
        return new static(
            $plugin_id,
            $plugin_definition,
            $configuration['field_definition'],
            $configuration['settings'],
            $configuration['label'],
            $configuration['view_mode'],
            $configuration['third_party_settings']
        );
    }

    /**
     * Show the elements
     * 
     * @param FieldItemListInterface $items    the items
     * @param string                 $langcode the language
     *                                         {@inheritdoc}
     * 
     * @return array
     */
    public function viewElements(FieldItemListInterface $items, $langcode) 
    {
        $element = [];

        return $element;
    }
}