<?php
/**
 * Field constraint validator
 * PHP version 8
 * 
 * @category Ephoto_Pluggin
 * @package  Ephoto-Drupal
 * @author   Einden <contact@einden.fr>
 * @license  https://www.ephoto.fr/ Einden
 * @link     https://www.ephoto.fr/
 */ 

namespace Drupal\ephoto_dam_field\Plugin\Validation\Constraint;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;



 /**
  * Validates the Ephoto Dam Field
  * 
  * @category Fiel_Constraint_Validator
  * @package  Ephoto-Drupal
  * @author   Einden <contact@einden.fr>
  * @license  https://www.ephoto.fr/ Einden
  * @link     https://www.ephoto.fr/
  */

class EphotoDamFieldConstraintValidator 
extends ConstraintValidator 
implements ContainerInjectionInterface
{
    /**
     * Create an instance of the validator.
     */
    public function __construct() 
    {
    
    }

    /**
     * Creates the Field constraint validator
     * 
     * @param ContainerInterface $container the container interface
     * 
     * @return EphotoDamFieldConstraintValidator
     *                                      {@inheritdoc}
     */
    public static function create(ContainerInterface $container) 
    {
        return new static();
    }

    /**
     * Validates the Field regarding given constraint
     * 
     * @param Media      $field      the media to be checked
     * @param Constraint $constraint the constraint to be respected
     * 
     * @return EphotoDamFieldConstraintValidator
     *                                      {@inheritdoc}
     */
    public function validate($field, Constraint $constraint) 
    {
        if (!isset($field->image_size)) {
            return null;
        }

        $test = empty($field->image_size) 
        || 
        preg_match('/^[0-9x]+$/', $field->image_size);

        $message = t(
            'The "Size" field must respect one of the following patterns: 

            "x{height}", "{width}x", "{width}x{height}" 
            or 
            "{width/height (detect auto)}". 

            Examples: "x500", "500x", "500x500" or "500".'
        );
        
        if (!$test) {
            $this->context->addViolation($message);
        }
    }
}
